@@ -12,7 +12,7 @@ from sklearn.metrics import pairwise_distances_argmin_min
 try:
 
     from keras.backend.tensorflow_backend import set_session
-except BaseExceptions as e:
+except BaseException as e:
     print("Keras Tensorflor Backend Failled With Error: ", e)
     print("Using most recent tensorflow keras backend...")
     from tensorflow.compat.v1.keras.backend import set_session
